@@ -28,24 +28,20 @@ def MakeRoute(data: Template) -> Route:
 
 
 def MakeDeparture(data: Template) -> List[Departure]:
+    data = data.copy()
     list_of_departure_days = [data.DDOW]\
         if not data.ADOW\
         else calc_departures(data.DDOW, data.ARDY)
      
     departures = []
     for departureDays in list_of_departure_days:
-        if not data.RODN:
-            data.RODN = calc_route_departure(departureDays, data.ARDY)
-
-        if data.ADOW:
-            data.ARDY = recalculate_lead_time(departureDays, data.ARDY)
-
-        if data.ARDX:
-            data.ARDY = int(data.ARDX)
-
+        RODN = calc_route_departure(departureDays, data.ARDY) if not data.RODN else data.RODN
+        ARDY = recalculate_lead_time(departureDays, data.ARDY) if data.ADOW else data.ARDY
+        ARDY = int(data.ARDX) if data.ARDX else data.ARDY
+    
         departure =  Departure(
             WWROUT = data.ROUT,
-            WWRODN = data.RODN,
+            WWRODN = RODN,
             WRRESP = data.DRSP,
             WRFWNO = data.FWNO,
             WRTRCA = data.TRCA,
@@ -63,7 +59,7 @@ def MakeDeparture(data: Template) -> List[Departure]:
             WRDETH = data.DETH,
             WRDETM = data.DETM,
             WRVFDT = datetime.now().strftime('%y%m%d'),
-            WRARDY = data.ARDY,
+            WRARDY = ARDY,
             WRARHH = data.ARHH,
             WRARMM = data.ARMM
         )
