@@ -91,8 +91,8 @@ RESP = Field(..., name='Responsible')
 SDES = Field(..., name='Place')
 DLMC = Field(..., name='Manual shipment scheduling allowed')
 DLAC = Field(..., name='Ignore deadline when connecting dely no')
-TSID = Field(..., name='Transportation service ID')
-CHB1 = Field(False, name='Yes/No')
+TSID = Field('', name='Transportation service ID')
+CHB1 = Field(0, name='Yes/No', max_digits=1)
 CMNT = Field(..., name='Comment') 
 
 
@@ -238,9 +238,9 @@ class CustomerExtension(BaseModel):
     Message: Optional[str] = Message
     FILE: str
     PK01: Optional[str] = PK01
-    N096: Optional[str] = N096
-    N196: Optional[str] = N196
-    N296: Optional[str] = N296
+    N096: Optional[NonNegativeInt] = N096
+    N196: Optional[NonNegativeInt] = N196
+    N296: Optional[NonNegativeInt] = N296
 
 
 
